@@ -470,6 +470,9 @@ class ConnectWiseAPIClient(object):
 
             # FieldTracker tracks Foreign Keys by database column name.
             # Remove _id to use the Django model field name.
+            # TODO note, this line is NOT NEEDED, just a red-herring.
+            #  It can be removed after refactoring. I'm still afraid to remove
+            #  if for now, in case I'm wrong and it breaks updates.
             field = field.replace('_id', '')
 
             if field and field in instance.EDITABLE_FIELDS:
@@ -1063,109 +1066,67 @@ class TicketAPIMixin:
         endpoint_url = self._endpoint(
             '{}/{}'.format(self.ENDPOINT_TICKETS, ticket.id)
         )
-        body = self._format_ticket_patch_body(ticket, changed_fields)
+        body = self._format_ticket_patch_body(changed_fields)
         return self.request('patch', endpoint_url, body)
 
-    def create_ticket(self, ticket, changed_fields):
+    def create_ticket(self, fields):
         endpoint_url = self._endpoint(
             '{}/'.format(self.ENDPOINT_TICKETS)
         )
-        # Changed fields is useful at this point as it prevents us
-        #  from sending an empty string, so the ticket is created with the
-        #  defaults from CW. I don't think this is the best way to handle it
-        #  though, and it should be updated to a new pattern during
-        #  the quick create records milestone.
-        # TODO remove changed fields to add new pattern
-        body = self._format_ticket_post_body(ticket, changed_fields)
+        body = self._format_ticket_post_body(fields)
         return self.request('POST', endpoint_url, body)
 
-    def _format_ticket_post_body(self, ticket, fields):
+    def _format_ticket_post_body(self, fields):
         # CW formats POST and PATCH very differently, thats why there are two
-        #  different methods for it./
+        #  different methods for it.
         # TODO reduce duplication between post/patch formatting after switch
         #  to synchronizers
-        # TODO Extract converting fields from their DB name to their API name
-        #  to their own method after switch to synchronizers
         body = {}
 
         for field, value in fields.items():
 
-            if field and ticket.record_type and \
-                    field in ticket.EDITABLE_FIELDS[ticket.record_type]:
+            if isinstance(value, datetime.datetime):
+                value = value.astimezone(
+                        pytz.timezone('UTC')).strftime(
+                        "%Y-%m-%dT%H:%M:%SZ")
+            elif isinstance(value, models.Model):
+                value = {'id': value.id}
+            else:
+                value = str(value) if value else ''
 
-                field = ticket.EDITABLE_FIELDS[ticket.record_type][field]
-
-                if isinstance(value, datetime.datetime):
-                    value = value.astimezone(
-                            pytz.timezone('UTC')).strftime(
-                            "%Y-%m-%dT%H:%M:%SZ")
-                elif isinstance(value, models.Model):
-                    value = {'id': value.id}
-                else:
-                    value = str(value) if value else ''
-
-                body[field] = value
+            body[field] = value
 
         return body
 
-    def _format_ticket_patch_body(self, ticket, changed_fields):
+    def _format_ticket_patch_body(self, changed_fields):
         # TODO reduce duplication between post/patch formatting after switch
         #  to synchronizers
-        # TODO Extract converting fields from their DB name to their API name
-        #  to their own method
         body = []
 
         for field, value in changed_fields.items():
 
-            if field and ticket.record_type and \
-                    field in ticket.EDITABLE_FIELDS[ticket.record_type]:
-                extra_field_updates = []
-                field_update = {
-                    'op': 'replace',
-                    'path': ticket.EDITABLE_FIELDS[ticket.record_type][field],
-                }
+            field_update = {
+                'op': 'replace',
+                'path': field,
+            }
 
-                if isinstance(value, datetime.datetime):
-                    field_update.update({
-                        'value': value.astimezone(
-                            pytz.timezone('UTC')).strftime(
-                                "%Y-%m-%dT%H:%M:%SZ")
-                    })
+            if isinstance(value, datetime.datetime):
+                field_update.update({
+                    'value': value.astimezone(
+                        pytz.timezone('UTC')).strftime(
+                            "%Y-%m-%dT%H:%M:%SZ")
+                })
 
-                elif field == \
-                        ticket.EDITABLE_FIELDS[ticket.record_type].get(
-                            'contact') and value is None:
-                    # If a contact is being cleared on a ticket, CW requires
-                    # that the following fields be cleared as well.
-                    contact_fields = [
-                        'contactName', 'contactPhoneNumber',
-                        'contactEmailAddress'
-                    ]
-                    field_update.update({
-                        'value': ''
-                    })
+            elif isinstance(value, models.Model):
+                field_update.update({
+                    'value': {
+                        'id': value.id,
+                    }
+                })
+            else:
+                field_update.update({'value': str(value) if value else ''})
 
-                    for contact_field in contact_fields:
-                        extra_field_updates.append(
-                            {
-                                'op': 'remove',
-                                'path': contact_field
-                            }
-                        )
-
-                elif isinstance(value, models.Model):
-                    field_update.update({
-                        'value': {
-                            'id': value.id,
-                        }
-                    })
-                else:
-                    field_update.update({'value': str(value) if value else ''})
-
-                body.append(field_update)
-
-                if extra_field_updates:
-                    body.extend(extra_field_updates)
+            body.append(field_update)
 
         return body
 
