@@ -29,6 +29,13 @@ NEEDED_CALLBACKS = [
     "objectId": 1,
     "level": "owner",
   },
+  {
+    "type": "contact",
+    "description": "Kanban application contact callback",
+    "url": None,
+    "objectId": 1,
+    "level": "owner",
+  },
   {
     "type": "opportunity",
     "description": "Kanban application opportunity callback",
